#!-PERL-
# mif2ps.pl
#
# THIS FILE IS COPYRIGHT 1994 BY TELENOR RESEARCH, NORWAY
#
#                    ALL RIGHTS RESERVED.
#
# For rights granted to the public see the COPYRIGHT file
#
# Programming : Jon Stephenson von Tetzchner

# This script is part of the fm2html package.

$\ = "\n";		# set output record separator
$, = " ";		# set output field separator
$* = 0;			# set single line pattern matching

select( STDERR );	# all error messages go to stderr
$| = 1;			# make stderr unbuffered

$FALSE = 0;
$TRUE  = 1;

$TMPNAME = "mif2ps.tmp";
$PRINT_SETTINGS_NAME = "mif2ps.printsettings";


sub escape	# take string, insert backslash before special characters
{
  local( $_ ) = @_;
  s|([\.\+\?\*\'\"\(\)])|\\$1|g;
  $_;
}

sub basename	# take pathname, strip leading directories and optional suffix
{
  local( $_, $suffix ) = @_;
  m|/|o && s|^.*/([^/]*)$|$1|;
  $suffix = &escape( $suffix );
  s|(.*)$suffix|$1|;
  $_;
}


local( $prog ) = &basename( $0 );
local( $usage ) = "Usage: $prog [-q] [-r] filename...";

local( $tmpfile, $script, $fmbatch, $version, $execpath );

local( $quiet ) = $FALSE;
local( $qflag ) = $FALSE;
local( $numfiles ) = 0;
local( $redirect ) = "1>&2";

while ( $ARGV[0] =~ m|^-| )
{
  $_ = shift;
  last if m|^--|;

  if ( m|^-q$| )
  {
    $quiet = $TRUE; $qflag = "-q"; next;
  }
  elsif ( m|^-r$| )
  {
    $remove = $TRUE; next;
  }

  print "$prog: ERROR: Invalid flag: \"$_\"";
  print "$usage";
  exit( 1 );
}

if ( $#ARGV == -1 )
{
  print "";
  print "$usage";
  print "";
  print "\tThe \"-q\" option specifies \"quiet\" mode.";
  print "\tThe \"-r\" option specifies that input files be removed afterward.";
  print "\tThe remaining arguments specify the names of MIF files to translate to PostScript.";
  print "";
  exit( 1 );
}

if ( $quiet == $TRUE )
{
  local( $tmpdir ) = $ENV{'TMPDIR'};
  local( $cwd ) = `pwd`;

  if ( ! $tmpdir ) { $tmpdir = "-TMPDIR-"; }
  if ( ! $tmpdir ) { chop( $tmpdir = "$cwd" ); }
  $tmpdir =~ s|/$||;
  $tmpfile = "$tmpdir/$TMPNAME.$$";
  $redirect = "1>$tmpfile 2>&1";
}

if ( $ENV{'MIF2PSPRINTSETTINGSFILE'} )
{
  $print_settings_file = $ENV{'MIF2PSPRINTSETTINGSFILE'};
}
else
{
  $print_settings_file = "-LIBDIR-/$PRINT_SETTINGS_NAME";
}

$quiet == $FALSE && print
  "\n$prog: Translating the following graphics files from MIF to PostScript";

while ( @ARGV )
{
  $miffiles[$numfiles] = shift;
  $quiet == $FALSE && print "  $miffiles[$numfiles]";
  $numfiles++;
}

$quiet == $FALSE && print "";

-e $print_settings_file ||
  die "$prog: Could not find print settings file \"$print_settings_file\"... exiting";

$script = <<END;
Open $print_settings_file
END

for ( $i = 0; $i < $numfiles; $i++ )
{
  $script .= <<END;
Open $miffiles[$i]
Print $miffiles[$i] $print_settings_file
Quit $miffiles[$i]
END
}

$script .= <<END;
Quit $print_settings_file
Quit
END

if ( open( INFILE, "<$miffiles[0]" ) )
{
  $idline = <INFILE>;
  $idline =~ m|^\S+\s+(.)|;
  $version = $1;
  close( INFILE );
}

if ( ! "-FMBATCH4-" )
{
  $fmbatch = "-FMBATCH3-";
}
elsif ( ! "-FMBATCH3-" )
{
  $fmbatch = "-FMBATCH4-";
}
elsif ( $version < 4 )
{
  $fmbatch = "-FMBATCH3-";
}
else
{
  $fmbatch = "-FMBATCH4-";
}

$execpath = "$fmbatch";
$execpath =~ s|^(\S+)\s*.*|$1|;

if ( ! -x "$execpath" )
  { die "$prog: ERROR: FrameMaker batch mode program \"$execpath\" is not executable... exiting"; }

eval open( FMBATCH, "| $fmbatch $redirect" );
print FMBATCH "$script";
close( FMBATCH );

if ( $? != 0 )
{
  if ( $quiet == $TRUE )
  {
    # djf: It would be nice to eliminate the need for $tmpfile by piping
    # fmbatch output directly to grep.  However, if you do that then the
    # status value returned by "close( FMBATCH )" is for the grep, not the
    # fmbatch job.
    eval system( "grep -i error $tmpfile 1>&2" );
    eval system( "rm -f $tmpfile 1>&2" );
  }
  die "$prog: ERROR: FrameMaker batch program \"$fmbatch\" failed... exiting";
}
eval system( "rm -f $tmpfile 1>&2" );

if ( $remove == $TRUE )
{
  $quiet == $FALSE && print "$prog: Deleting MIF input files...";

  for ( $i = 0; $i < $numfiles; $i++ )
  {
    eval system( "rm -f $miffiles[$i]" );
  }
}

$quiet == $FALSE && print "$prog: Done\n";

exit( 0 );
